cmd

package
v0.6.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 16, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Copyright © 2024 Agung Firmansyah gnoega@gmail.com

Copyright © 2024 Agung Firmansyah gnoega@gmail.com

Copyright © 2024 Agung Firmansyah gnoega@gmail.com

Copyright © 2024 Agung Firmansyah gnoega@gmail.com

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type Calendar

type Calendar struct {
	// contains filtered or unexported fields
}

func NewCalendar

func NewCalendar() *Calendar

func (*Calendar) Filter

func (c *Calendar) Filter()

func (*Calendar) GetEvents

func (c *Calendar) GetEvents(service *calendar.Service)

func (*Calendar) Render

func (c *Calendar) Render()

type EventList

type EventList struct {
	Summary   string
	Start     string
	End       string
	Attendees []string
	Link      string
}

type Flags

type Flags struct {
	// contains filtered or unexported fields
}

func NewFlags

func NewFlags() *Flags

type Show

type Show string
const (
	Table Show = "table"
	List  Show = "list"
)

func (*Show) Set

func (s *Show) Set(v string) error

func (*Show) String

func (s *Show) String() string

func (*Show) Type

func (s *Show) Type() string

Jump to